@@ -1,9 +1,9 @@
 import warnings
 
-warnings.filterwarnings("always")
+warnings.filterwarnings("ignore")
 
 from .element import Element, SpecialElement
 from .compound import Compound, FormulaCompound
 from .reaction import Reaction ,CombustionTrain
 
-from chemsolve.utils.constants import *
\ No newline at end of file
+from .utils.constants import *
\ No newline at end of file
